# core-image-publisher
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""Integration tests for the kombu queue code."""

import kombu
import kombu.simple
from testtools import TestCase


from core_image_publisher.queue import CoreImagePublisherQueueMonitor


class KombuQueueIntegrationTests(TestCase):

    def test_can_read_message(self):
        conn = kombu.Connection('memory:///')
        queue_message(conn, {'test': 'value'})

        consumer = LoggingConsumer()
        q = CoreImagePublisherQueueMonitor(conn, consumer)
        # pump the queue to get the enqueued message:
        next(q.consume(limit=1, timeout=5.0))

        self.assertEqual(consumer.got_messages, [dict(test='value')])

    def test_uncaught_exceptions_cause_message_requeue(self):
        conn = kombu.Connection('memory:///')
        queue_message(conn, {'test': 'value'})

        def consumer_with_bug(message):
            raise RuntimeError("I am a bug, all up in ur bizniz!")

        logging_consumer = LoggingConsumer()

        queue_bugged = CoreImagePublisherQueueMonitor(conn, consumer_with_bug)
        queue_ok = CoreImagePublisherQueueMonitor(conn, logging_consumer)

        # pump the queue to get the enqueued message:
        next(queue_bugged.consume(limit=1, timeout=5.0))
        next(queue_ok.consume(limit=1, timeout=5.0))

        self.assertEqual(logging_consumer.got_messages, [dict(test='value')])



class LoggingConsumer(object):

    """A consumer callback object that acks and logs all received payloads."""

    def __init__(self):
        self.got_messages = []

    def __call__(self, message):
        self.got_messages.append(message.payload)
        message.ack()


def queue_message(conn, message):
    q = kombu.simple.SimpleQueue(conn, 'core.image.v1')
    q.put(message)

