# core-image-publisher
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""Business logic or the service lives here."""

from core_image_publisher.queue import enqueue_message


def logging_worker(message):
    logger.info("Got %r", message.payload, extra=message.payload)
    payload = message.payload
    try:
        image_name = payload['image_name']
        channel = payload['channel']
        device = payload['device']
    except KeyError as e:
        logger.error(
            "Unable to deserialize message payload - rejecting message: %s",
            s,
            extra=payload
        )
        message.reject()
        return

    image_path = download_image(image_name, channel, device)
    nova_image_path = convert_nova_image(image_path)
    glance_image_name = upload_image_to_glance(nova_image_path)

    payload['nova_image'] = glance_image_name
    enqueue_message(payload)
    message.ack()


def download_image(name, channel, device):
    """Download the ubuntu code image, return a path to it on disk."""


def convert_nova_image(image_path):
    """Convert a core image to a nova image, return path to the converted image."""


def upload_image_to_glance(nova_image_path):
    """Upload the nova image to glance, returning the name of the image in glance."""

